@@ -101,7 +101,7 @@ namespace barcodeRecognition {
    *  @author Sebastian Held <sebastian.held@gmx.de>
    */
   class barcodeRecognitionThread : public TQObject, public TQThread {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     barcodeRecognitionThread();
