@@ -28,7 +28,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class ComicBookCollection : public Collection {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
