@@ -100,7 +100,7 @@ bool DropHandler::handleURL(const KURL::List& urls_) {
       hasUnknown = true;
     }
   }
-  MainWindow* mainWindow = ::tqqt_cast<MainWindow*>(Kernel::self()->widget());
+  MainWindow* mainWindow = ::tqt_cast<MainWindow*>(Kernel::self()->widget());
   if(!mainWindow) {
     myDebug() << "DropHandler::handleURL() - no main window!" << endl;
     return !hasUnknown;
