@@ -20,7 +20,7 @@
 namespace Tellico {
 
 class DropHandler : public TQObject {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
