@@ -26,7 +26,7 @@ namespace TDEIO {
 namespace Tellico {
 
 class NetAccess : public TQObject {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
