@@ -33,7 +33,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class ArxivFetcher : public Fetcher {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
