@@ -40,7 +40,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class DiscogsFetcher : public Fetcher {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
