@@ -131,10 +131,10 @@ void EntrezFetcher::search(FetchKey key_, const TQString& value_) {
   m_step = Search;
 //  myLog() << "EntrezFetcher::doSearch() - url: " << u.url() << endl;
   m_job = TDEIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
-          TQT_SLOT(slotComplete(TDEIO::Job*)));
+  connect(m_job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQ_SIGNAL(result(TDEIO::Job*)),
+          TQ_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void EntrezFetcher::continueSearch() {
@@ -256,10 +256,10 @@ void EntrezFetcher::doSummary() {
   m_step = Summary;
 //  myLog() << "EntrezFetcher::searchResults() - url: " << u.url() << endl;
   m_job = TDEIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
-          TQT_SLOT(slotComplete(TDEIO::Job*)));
+  connect(m_job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQ_SIGNAL(result(TDEIO::Job*)),
+          TQ_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void EntrezFetcher::summaryResults() {
