@@ -15,7 +15,7 @@
 #include "fetchmanager.h"
 #include "../tellico_kernel.h"
 
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 using Tellico::Fetch::ManagerMessage;
 
