@@ -36,7 +36,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class YahooFetcher : public Fetcher {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
