@@ -517,9 +517,9 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
 
   m_usePreset = new TQCheckBox(i18n("Use preset &server:"), optionsWidget());
   l->addWidget(m_usePreset, ++row, 0);
-  connect(m_usePreset, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotTogglePreset(bool)));
+  connect(m_usePreset, TQ_SIGNAL(toggled(bool)), TQ_SLOT(slotTogglePreset(bool)));
   m_serverCombo = new GUI::ComboBox(optionsWidget());
-  connect(m_serverCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotPresetChanged()));
+  connect(m_serverCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotPresetChanged()));
   l->addWidget(m_serverCombo, row, 1);
   ++row;
   l->addMultiCellWidget(new KSeparator(optionsWidget()), row, row, 0, 1);
@@ -528,8 +528,8 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   TQLabel* label = new TQLabel(i18n("Hos&t: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_hostEdit = new GUI::LineEdit(optionsWidget());
-  connect(m_hostEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
-  connect(m_hostEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SIGNAL(signalName(const TQString&)));
+  connect(m_hostEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
+  connect(m_hostEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SIGNAL(signalName(const TQString&)));
   l->addWidget(m_hostEdit, row, 1);
   TQString w = i18n("Enter the host name of the server.");
   TQWhatsThis::add(label, w);
@@ -539,7 +539,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   label = new TQLabel(i18n("&Port: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_portSpinBox = new KIntSpinBox(0, 999999, 1, Z3950_DEFAULT_PORT, 10, optionsWidget());
-  connect(m_portSpinBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotSetModified()));
+  connect(m_portSpinBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_portSpinBox, row, 1);
   w = i18n("Enter the port number of the server. The default is %1.").arg(Z3950_DEFAULT_PORT);
   TQWhatsThis::add(label, w);
@@ -549,7 +549,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   label = new TQLabel(i18n("&Database: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_databaseEdit = new GUI::LineEdit(optionsWidget());
-  connect(m_databaseEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_databaseEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_databaseEdit, row, 1);
   w = i18n("Enter the database name used by the server.");
   TQWhatsThis::add(label, w);
@@ -563,7 +563,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   m_charSetCombo->insertItem(TQString::fromLatin1("marc8"));
   m_charSetCombo->insertItem(TQString::fromLatin1("iso-8859-1"));
   m_charSetCombo->insertItem(TQString::fromLatin1("utf-8"));
-  connect(m_charSetCombo, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_charSetCombo, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_charSetCombo, row, 1);
   w = i18n("Enter the character set encoding used by the z39.50 server. The most likely choice "
            "is MARC-8, although ISO-8859-1 is common as well.");
@@ -580,7 +580,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   m_syntaxCombo->insertItem(TQString::fromLatin1("UNIMARC"), TQString::fromLatin1("unimarc"));
   m_syntaxCombo->insertItem(TQString::fromLatin1("USMARC"), TQString::fromLatin1("usmarc"));
   m_syntaxCombo->insertItem(TQString::fromLatin1("GRS-1"), TQString::fromLatin1("grs-1"));
-  connect(m_syntaxCombo, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_syntaxCombo, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_syntaxCombo, row, 1);
   w = i18n("Enter the data format used by the z39.50 server. Tellico will attempt to "
            "automatically detect the best setting if <i>auto-detect</i> is selected.");
@@ -592,7 +592,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   l->addWidget(label, ++row, 0);
   m_userEdit = new GUI::LineEdit(optionsWidget());
   m_userEdit->setHint(i18n("Optional"));
-  connect(m_userEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_userEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_userEdit, row, 1);
   w = i18n("Enter the authentication user name used by the z39.50 database. Most servers "
            "do not need one.");
@@ -605,7 +605,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
   m_passwordEdit = new GUI::LineEdit(optionsWidget());
   m_passwordEdit->setHint(i18n("Optional"));
   m_passwordEdit->setEchoMode(TQLineEdit::Password);
-  connect(m_passwordEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_passwordEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_passwordEdit, row, 1);
   w = i18n("Enter the authentication password used by the z39.50 database. Most servers "
            "do not need one. The password will be saved in plain text in the Tellico "
