@@ -40,7 +40,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class GroupView : public GUI::ListView, public Observer {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
