@@ -28,7 +28,7 @@ namespace Tellico {
   namespace GUI {
 
 class SpinBox : public TQSpinBox {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
@@ -39,7 +39,7 @@ public:
  * @author Robby Stephenson
  */
 class DateWidget : public TQWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
