@@ -121,12 +121,12 @@ FieldWidget::FieldWidget(Data::FieldPtr field_, TQWidget* parent_, const char* n
   m_editMultiple = new TQCheckBox(this);
   m_editMultiple->setChecked(true);
   m_editMultiple->setFixedWidth(m_editMultiple->sizeHint().width()); // don't let it have any extra space
-  connect(m_editMultiple, TQT_SIGNAL(toggled(bool)), TQT_SLOT(setEnabled(bool)));
+  connect(m_editMultiple, TQ_SIGNAL(toggled(bool)), TQ_SLOT(setEnabled(bool)));
   l->addWidget(m_editMultiple);
 
   TQWhatsThis::add(this, field_->description());
   // after letting the subclass get created, insert default value
-  TQTimer::singleShot(0, this, TQT_SLOT(insertDefault()));
+  TQTimer::singleShot(0, this, TQ_SLOT(insertDefault()));
 }
 
 void FieldWidget::insertDefault() {
@@ -166,10 +166,10 @@ void FieldWidget::editMultiple(bool show_) {
   // FIXME: maybe modified should only be signaled when the button is toggle on
   if(show_) {
     m_editMultiple->show();
-    connect(m_editMultiple, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(modified()));
+    connect(m_editMultiple, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(modified()));
   } else {
     m_editMultiple->hide();
-    disconnect(m_editMultiple, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(modified()));
+    disconnect(m_editMultiple, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(modified()));
   }
   // the widget length needs to be updated since it gets shorter
   widget()->updateGeometry();
