@@ -28,16 +28,16 @@ using Tellico::GUI::ListViewItem;
 ListView::ListView(TQWidget* parent_, const char* name_) : TDEListView(parent_, name_/*=0*/),
     m_sortStyle(SortByText), m_isClear(true) {
   setSelectionMode(TQListView::Extended);
-  connect(this, TQT_SIGNAL(selectionChanged()),
-          TQT_SLOT(slotSelectionChanged()));
-  connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-          TQT_SLOT(slotDoubleClicked(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(selectionChanged()),
+          TQ_SLOT(slotSelectionChanged()));
+  connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+          TQ_SLOT(slotDoubleClicked(TQListViewItem*)));
 #if !KDE_IS_VERSION(3,3,90)
   m_shadeSortColumn = false;
   // call it once to initialize
   slotUpdateColors();
 #endif
-  connect(kapp, TQT_SIGNAL(tdedisplayPaletteChanged()), TQT_SLOT(slotUpdateColors()));
+  connect(kapp, TQ_SIGNAL(tdedisplayPaletteChanged()), TQ_SLOT(slotUpdateColors()));
   m_comparisons.setAutoDelete(true);
 }
 
@@ -234,7 +234,7 @@ void ListView::drawContentsOffset(TQPainter* p, int ox, int oy, int cx, int cy,
 /* ****************** ListViewItem ********************* */
 
 ListViewItem::~ListViewItem() {
-  // I think there's a bug in qt where the children of this item are deleted after the item itself
+  // I think there's a bug in tqt where the children of this item are deleted after the item itself
   // as a result, there is no listView() pointer for the children, that obvious causes
   // a problem with updating the selection. So we MUST call clear() here ourselves!
   clear();
