@@ -26,7 +26,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class ParaFieldWidget : public FieldWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
