@@ -31,7 +31,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class RatingWidget : public TQHBox {
-Q_OBJECT
+TQ_OBJECT
   
 
 typedef TQPtrList<TQLabel> LabelList;
