@@ -37,7 +37,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class StringMapDialog : public KDialogBase {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
