@@ -33,7 +33,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class LoanDialog : public KDialogBase {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
