@@ -65,7 +65,7 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, progressLabel(), true);
   item.setTotalSteps(numFiles);
-  connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+  connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
   ProgressItem::Done done(this);
 
   TQStringList covers;
@@ -86,7 +86,7 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
 
     bool readNextLine = true;
     ts.unsetDevice();
-    ts.setDevice(TQT_TQIODEVICE(&file));
+    ts.setDevice(&file);
     TQString line;
     while(!ts.atEnd()) {
       if(readNextLine) {
@@ -190,7 +190,7 @@ TQWidget* AlexandriaImporter::widget(TQWidget* parent_, const char* name_/*=0*/)
   m_widget = new TQWidget(parent_, name_);
   TQVBoxLayout* l = new TQVBoxLayout(m_widget);
 
-  TQGroupBox* box = new TQGroupBox(2, Qt::Horizontal, i18n("Alexandria Options"), m_widget);
+  TQGroupBox* box = new TQGroupBox(2, TQt::Horizontal, i18n("Alexandria Options"), m_widget);
   TQLabel* label = new TQLabel(i18n("&Library:"), box);
   m_library = new KComboBox(box);
   label->setBuddy(m_library);
