@@ -56,7 +56,7 @@ Tellico::Data::CollPtr PDFImporter::collection() {
 
   ProgressItem& item = ProgressManager::self()->newProgressItem(this, progressLabel(), true);
   item.setTotalSteps(urls().count());
-  connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+  connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
   ProgressItem::Done done(this);
   const bool showProgress = options() & ImportProgress;
 
