@@ -24,7 +24,7 @@ namespace Tellico {
  * @author Robby Stephenson
 */
 class ReferencerImporter : public XSLTImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
