@@ -33,7 +33,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class TellicoImporter : public DataImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
