@@ -25,7 +25,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class TextImporter : public Importer {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
