@@ -28,7 +28,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class XSLTImporter : public TextImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
